@@ -27,6 +27,7 @@
 #' @param interval.seconds How long to wait between attempts
 #' @param max.attempts Number of API attempts before stopping
 #' @param validate Weather to submit report definition for validation before requesting the data.
+#' @param enqueueOnly only enqueue the report, don't get the data. returns report id, which you can later use to get the data
 #'
 #' @importFrom jsonlite toJSON unbox
 #'
@@ -42,14 +43,21 @@
 #'                                     element="page",
 #'                                     pathpattern
 #'                                     )
-#'
+#' enqueued.report.id <- QueuePathing("your_report_suite",
+#'                                     "2014-04-01",
+#'                                     "2014-04-20",
+#'                                     metric="pageviews",
+#'                                     element="page",
+#'                                     pathpattern,
+#'                                     enqueueOnly=TRUE
+#'                                     )
 #' }
 #'
 #' @export
 
 QueuePathing <- function(reportsuite.id, date.from, date.to, metric, element, pattern,
                         top=1000, start=1,
-                        segment.id='', expedite=FALSE,interval.seconds=5,max.attempts=120,validate=TRUE) {
+                        segment.id='', expedite=FALSE,interval.seconds=5,max.attempts=120,validate=TRUE,enqueueOnly=FALSE) {
 
   # build JSON description
   # we have to use unbox to force jsonlist not put strings into single-element arrays
@@ -82,7 +90,7 @@ QueuePathing <- function(reportsuite.id, date.from, date.to, metric, element, pa
                                                             startingWith = unbox(start),
                                                             pattern = as.list(pattern)))
 
-  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate)
+  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate,enqueueOnly=enqueueOnly)
 
   return(report.data)
 
