@@ -39,6 +39,7 @@
 #' @param interval.seconds How long to wait between attempts
 #' @param max.attempts Number of API attempts before stopping
 #' @param validate Weather to submit report definition for validation before requesting the data.
+#' @param enqueueOnly only enqueue the report, don't get the data. returns report id, which you can later use to get the data
 #'
 #' @importFrom jsonlite toJSON unbox
 #' @importFrom plyr rbind.fill
@@ -63,7 +64,15 @@
 #'                        elements = "product",
 #'                        classification = "Product Group"
 #'                        )
-#'
+#'  enqueued.report.id <- QueueRanked(
+#'                        reportsuite.id = your_report_suite, 
+#'                        date.from = "2016-03-30", 
+#'                        date.to = "2016-03-30",
+#'                        metrics = "orders",
+#'                        elements = "product",
+#'                        classification = "Product Group",
+#'                        enqueueOnly = TRUE
+#'                        )
 #' }
 #'
 #' @export
@@ -71,7 +80,7 @@
 QueueRanked <- function(reportsuite.id, date.from, date.to, metrics, elements,
                         top=10,start=1,selected=c(), search=c(),search.type='or',
                         segment.id='', segment.inline='', classification=c(),data.current=FALSE,
-                        expedite=FALSE,interval.seconds=5,max.attempts=120,validate=TRUE) {
+                        expedite=FALSE,interval.seconds=5,max.attempts=120,validate=TRUE,enqueueOnly=FALSE) {
 
   # build JSON description
   # we have to use unbox to force jsonlist not put strings into single-element arrays
@@ -150,7 +159,7 @@ QueueRanked <- function(reportsuite.id, date.from, date.to, metrics, elements,
   }
   report.description$reportDescription$elements <- elements.formatted
 
-  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate)
+  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate,enqueueOnly=enqueueOnly)
 
   return(report.data)
 
