@@ -43,10 +43,11 @@
 #' @param interval.seconds How long to wait between attempts
 #' @param max.attempts Number of API attempts before stopping
 #' @param validate Weather to submit report definition for validation before requesting the data.
+#' @param enqueueOnly only enqueue the report, don't get the data. returns report id, which you can later use to get the data
 #'
 #' @importFrom jsonlite toJSON unbox
 #'
-#' @return Data frame
+#' @return Data frame or report id, if enqueueOnly is TRUE
 #'
 #' @examples
 #' \dontrun{
@@ -63,7 +64,7 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
                         top=0,start=0,selected=c(),search=c(),search.type='or',
                         date.granularity='day', segment.id='', segment.inline='', classification = character(0),
                         anomaly.detection=FALSE, data.current=FALSE, expedite=FALSE,
-                        interval.seconds=5,max.attempts=120,validate=TRUE) {
+                        interval.seconds=5,max.attempts=120,validate=TRUE,enqueueOnly=FALSE) {
 
   if(anomaly.detection==TRUE && length(elements)>1) {
     print("Warning: Anomaly detection will not be used, as it only works for a single element.")
@@ -153,7 +154,7 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
   }
   report.description$reportDescription$elements <- elements.formatted
 
-  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate)
+  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate,enqueueOnly=enqueueOnly)
 
   return(report.data)
 
