@@ -3,7 +3,7 @@ test_that("Validate BuildClassificationValueSegment using legacy credentials", {
   skip_on_cran()
   
   #Correct [masked] credentials
-  #SCAuth(Sys.getenv("USER", ""), Sys.getenv("SECRET", ""))
+  SCAuth(Sys.getenv("USER", ""), Sys.getenv("SECRET", ""))
   
   aa <- BuildClassificationValueSegment("page",
                                         c("julia", "python", "hadoop"),
